@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .OverlayContainer import *
-from .IOverlayParent import *
+from .OverlayContainer import OverlayContainer
+from .IOverlayParent import IOverlayParent
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 Text = TypeVar["net.minecraft.text.Text"]
