@@ -1,8 +1,8 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .AbstractMapSettingContainer import *
-from .SettingsOverlay import *
+from .AbstractMapSettingContainer import AbstractMapSettingContainer
+from .SettingsOverlay import SettingsOverlay
 
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
