@@ -1,9 +1,9 @@
 from typing import overload
 from typing import TypeVar
-from .OverlayContainer import *
-from .IOverlayParent import *
+from .OverlayContainer import OverlayContainer
+from .IOverlayParent import IOverlayParent
 
-Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.jsmacros.client.gui.overlays.ConfirmOverlay_"]
+Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.wagyourgui.overlays.ConfirmOverlay_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 Text = TypeVar["net.minecraft.text.Text"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
