@@ -2,9 +2,9 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .AbstractRenderCodeCompiler import *
-from .EditorScreen import *
-from .AutoCompleteSuggestion import *
+from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
+from .EditorScreen import EditorScreen
+from .AutoCompleteSuggestion import AutoCompleteSuggestion
 
 Runnable = TypeVar["java.lang.Runnable"]
 
