@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .EntityHelper import *
+from .BaseEvent import BaseEvent
+from .EntityHelper import EntityHelper
 
 DamageSource = TypeVar["net.minecraft.entity.damage.DamageSource"]
 
 class EventDamage(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	attacker: EntityHelper
 	source: str
 	health: float
