@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .EntityHelper import *
+from .BaseEvent import BaseEvent
+from .EntityHelper import EntityHelper
 
 Entity = TypeVar["net.minecraft.entity.Entity"]
 
