@@ -1,5 +1,5 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventFallFlying(BaseEvent):
