@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .OverlayContainer import *
-from .IOverlayParent import *
-from .FileChooser_fileObj import *
+from .OverlayContainer import OverlayContainer
+from .IOverlayParent import IOverlayParent
+from .FileChooser_fileObj import FileChooser_fileObj
 
 Consumer = TypeVar["java.util.function.Consumer_java.io.File_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
