@@ -1,4 +1,4 @@
-from .History_HistoryStep import *
+from .History_HistoryStep import History_HistoryStep
 
 
 class History_Remove(History_HistoryStep):
