@@ -1,6 +1,6 @@
 from typing import overload
 from typing import List
-from .IContainerParent import *
+from .IContainerParent import IContainerParent
 
 
 class ICategoryTreeParent(IContainerParent):
