@@ -1,8 +1,8 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .BaseScreen import *
-from .Core import *
+from .BaseScreen import BaseScreen
+from .Core import Core
 
 KeyBinding = TypeVar["net.minecraft.client.option.KeyBinding"]
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
@@ -55,6 +55,10 @@ class JsMacros(ClientModInitializer):
 	def range(self, start: int, end: int, iter: int) -> List[int]:
 		pass
 
+	@overload
+	def tryAutoCastNumber(self, returnType: Class, number: object) -> object:
+		pass
+
 	pass
 
 
