@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .ScriptTrigger_TriggerType import *
-from .MacroScreen import *
+from .MultiElementContainer import MultiElementContainer
+from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
+from .MacroScreen import MacroScreen
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
