@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .IBeaconScreen import *
+from .IBeaconScreen import IBeaconScreen
 
 StatusEffect = TypeVar["net.minecraft.entity.effect.StatusEffect"]
 
