@@ -1,5 +1,5 @@
 from typing import overload
-from .ILoomScreen import *
+from .ILoomScreen import ILoomScreen
 
 
 class MixinLoomScreen(ILoomScreen):
