@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .IPlayerListHud import *
+from .IPlayerListHud import IPlayerListHud
 
 Text = TypeVar["net.minecraft.text.Text"]
 
