@@ -1,9 +1,9 @@
 from typing import overload
 from typing import TypeVar
-from .BaseScreen import *
+from .BaseScreen import BaseScreen
 
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
-ConfigScreenFactory = TypeVar["com.terraformersmc.modmenu.api.ConfigScreenFactory_xyz.wagyourtail.jsmacros.client.gui.screens.BaseScreen_"]
+ConfigScreenFactory = TypeVar["com.terraformersmc.modmenu.api.ConfigScreenFactory_xyz.wagyourtail.wagyourgui.BaseScreen_"]
 
 class ModMenuEntry_JsMacroScreen(ConfigScreenFactory):
 
