@@ -1,6 +1,6 @@
 from typing import overload
 from typing import List
-from .OptionType import *
+from .OptionType import OptionType
 
 
 class Option:
