@@ -1,12 +1,15 @@
 from typing import overload
 from typing import TypeVar
-from .LivingEntityHelper import *
-from .PlayerAbilitiesHelper import *
-from .ItemStackHelper import *
+from typing import Generic
+from .LivingEntityHelper import LivingEntityHelper
+from .PlayerAbilitiesHelper import PlayerAbilitiesHelper
+from .ItemStackHelper import ItemStackHelper
 
-T = TypeVar["T"]
+T = TypeVar("T")
 
-class PlayerEntityHelper(LivingEntityHelper):
+class PlayerEntityHelper(Generic[T], LivingEntityHelper):
+	"""
+	"""
 
 	@overload
 	def __init__(self, e: T) -> None:
@@ -14,42 +17,75 @@ class PlayerEntityHelper(LivingEntityHelper):
 
 	@overload
 	def getAbilities(self) -> PlayerAbilitiesHelper:
+		"""
+		Since: 1.0.3 
+		"""
 		pass
 
 	@overload
 	def getMainHand(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getOffHand(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getHeadArmor(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getChestArmor(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getLegArmor(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getFootArmor(self) -> ItemStackHelper:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getXP(self) -> int:
+		"""
+		Since: 1.2.5 [citation needed] 
+		"""
 		pass
 
 	@overload
 	def isSleeping(self) -> bool:
+		"""
+		Since: 1.2.5 [citation needed] 
+		"""
 		pass
 
 	@overload
 	def isSleepingLongEnough(self) -> bool:
+		"""
+		Since: 1.2.5 [citation needed] 
+
+		Returns:
+			if the player has slept the minimum ammount of time to pass the night. 
+		"""
 		pass
 
 	@overload
