@@ -1,10 +1,12 @@
 from typing import overload
-from .PositionCommon_Pos2D import *
-from .PositionCommon_Pos3D import *
-from .PositionCommon_Vec2D import *
+from .PositionCommon_Pos3D import PositionCommon_Pos3D
+from .PositionCommon_Vec2D import PositionCommon_Vec2D
 
 
 class PositionCommon_Pos2D:
+	"""
+	Since: 1.2.6 [citation needed] 
+	"""
 	ZERO: "PositionCommon_Pos2D"
 	x: float
 	y: float
