@@ -1,12 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .PositionCommon_Pos2D import *
-from .PositionCommon_Pos3D import *
-from .PositionCommon_Vec3D import *
+from .PositionCommon_Pos2D import PositionCommon_Pos2D
+from .PositionCommon_Vec3D import PositionCommon_Vec3D
 
 Vec3d = TypeVar["net.minecraft.util.math.Vec3d"]
 
 class PositionCommon_Pos3D(PositionCommon_Pos2D):
+	"""
+	Since: 1.2.6 [citation needed] 
+	"""
 	ZERO: "PositionCommon_Pos3D"
 	z: float
 
