@@ -1,9 +1,9 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .AbstractSettingContainer import *
-from .SettingsOverlay import *
-from .SettingsOverlay_SettingField import *
+from .AbstractSettingContainer import AbstractSettingContainer
+from .SettingsOverlay import SettingsOverlay
+from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
