@@ -1,6 +1,7 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
+from typing import Set
 
 Prism4j_Grammar = TypeVar["io.noties.prism4j.Prism4j.Grammar"]
 Prism4j_Node = TypeVar["io.noties.prism4j.Prism4j.Node"]
@@ -21,7 +22,7 @@ class Prism(GrammarLocator):
 		pass
 
 	@overload
-	def languages(self) -> List[str]:
+	def languages(self) -> Set[str]:
 		pass
 
 	pass
