@@ -1,11 +1,13 @@
 from typing import overload
 from typing import TypeVar
-from .RenderCommon_RenderElement import *
-from .RenderCommon_Image import *
+from .RenderCommon_RenderElement import RenderCommon_RenderElement
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 
 class RenderCommon_Image(RenderCommon_RenderElement):
+	"""
+	Since: 1.2.3 
+	"""
 	rotation: float
 	x: int
 	y: int
@@ -25,18 +27,48 @@ class RenderCommon_Image(RenderCommon_RenderElement):
 
 	@overload
 	def setPos(self, x: int, y: int, width: int, height: int) -> None:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			x: 
+			width: 
+			y: 
+			height: 
+		"""
 		pass
 
 	@overload
 	def setRotation(self, rotation: float) -> "RenderCommon_Image":
+		"""
+		Since: 1.2.6 
+
+		Args:
+			rotation: 
+		"""
 		pass
 
 	@overload
 	def setImage(self, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> None:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			imageY: 
+			textureWidth: 
+			imageX: 
+			regionHeight: 
+			id: 
+			regionWidth: 
+			textureHeight: 
+		"""
 		pass
 
 	@overload
 	def getImage(self) -> str:
+		"""
+		Since: 1.2.3 
+		"""
 		pass
 
 	@overload
