@@ -1,18 +1,17 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .CancelScreen import *
-from .ScriptContext import *
+from .MultiElementContainer import MultiElementContainer
+from .BaseScriptContext import BaseScriptContext
+from .CancelScreen import CancelScreen
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
-WeakReference = TypeVar["java.lang.ref.WeakReference_xyz.wagyourtail.jsmacros.core.language.ScriptContext___"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
 class RunningContextContainer(MultiElementContainer):
-	t: WeakReference
+	t: BaseScriptContext
 
 	@overload
-	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: CancelScreen, t: ScriptContext) -> None:
+	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: CancelScreen, t: BaseScriptContext) -> None:
 		pass
 
 	@overload
