@@ -1,9 +1,11 @@
 from typing import overload
 from typing import List
-from .ScriptTrigger_TriggerType import *
 
 
 class ScriptTrigger_TriggerType:
+	"""
+	Since: 1.0.0 [citation needed] 
+	"""
 	KEY_FALLING: "ScriptTrigger_TriggerType"
 	KEY_RISING: "ScriptTrigger_TriggerType"
 	KEY_BOTH: "ScriptTrigger_TriggerType"
