@@ -1,14 +1,14 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .Option import *
+from typing import Generic
+from .Option import Option
 
 Field = TypeVar["java.lang.reflect.Field"]
-T = TypeVar["T"]
-List = TypeVar["java.util.List_T_"]
+T = TypeVar("T")
 Method = TypeVar["java.lang.reflect.Method"]
 
-class SettingsOverlay_SettingField:
+class SettingsOverlay_SettingField(Generic[T]):
 	type: Class
 	option: Option
 
